@@ -16,19 +16,15 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
 
 #include "seahorse-application.h"
-#include "seahorse-common.h"
 
-#include "pgp/seahorse-pgp.h"
-#include "ssh/seahorse-ssh.h"
+#include "seahorse-common.h"
 
 #include "seahorse-search-provider.h"
 
@@ -89,30 +85,12 @@ seahorse_application_finalize (GObject *gobject)
 	G_OBJECT_CLASS (seahorse_application_parent_class)->finalize (gobject);
 }
 
-#ifdef WITH_PKCS11
-void seahorse_pkcs11_backend_initialize (void);
-#endif
-
-void seahorse_gkr_backend_initialize (void);
-
 static void
 seahorse_application_startup (GApplication *application)
 {
 	/* Insert Icons into Stock */
 	seahorse_icons_init ();
 
-	/* Initialize the various components */
-#ifdef WITH_PGP
-	seahorse_pgp_backend_initialize ();
-#endif
-#ifdef WITH_SSH
-	seahorse_ssh_backend_initialize ();
-#endif
-#ifdef WITH_PKCS11
-	seahorse_pkcs11_backend_initialize ();
-#endif
-	seahorse_gkr_backend_initialize ();
-
 	seahorse_search_provider_initialize (SEAHORSE_APPLICATION (application)->search_provider);
 
 	/* HACK: get the inactivity timeout started */
