@@ -15,9 +15,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -28,12 +27,12 @@
 #include "seahorse-ssh-operation.h"
 
 #include "seahorse-common.h"
-#include "seahorse-object.h"
-#include "seahorse-object-list.h"
-#include "seahorse-util.h"
+
+#include "libseahorse/seahorse-object.h"
+#include "libseahorse/seahorse-object-list.h"
+#include "libseahorse/seahorse-util.h"
 
 #include <glib/gi18n.h>
-
 #include <glib.h>
 #include <glib-object.h>
 
